import matlab.engine
import multiprocessing as mp

engines = {}

def start_matlab_engine():
    eng = matlab.engine.start_matlab()
    eng.addpath('FUCCI')
    engines[mp.current_process().pid] = eng

def stop_matlab_engine():
    eng = engines.pop(mp.current_process().pid, None)
    if eng:
        eng.quit()



from io import open

from setuptools import setup

with open('requirements.txt', 'r') as f:
    requirements = f.read().splitlines()

# Note: removed all identity information from this file

setup(name='rsnl',
      version='0.0.11',
      description='Package for RSNL algorithm for \
                   simulation-based inference',
      license='GPL',
      packages=['rsnl'],
      zip_safe=False,
      python_requires='>=3.7',
      install_requires=requirements
      )
